@@ -16,7 +16,7 @@ author = 'Diony Rosa'
 extensions = []
 
 templates_path = ['_templates']
-exclude_patterns = ['cli_prolog.rst']
+exclude_patterns = ['cli/generated.rst']
 
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
